==> Paws-0.16.tar.gz: Paws-0.16/lib/Paws/WAF/DeleteIPSet.pm <==

package Paws::WAF::DeleteIPSet;
  use Moose;
  has ChangeToken => (is => 'ro', isa => 'Str', required => 1);
  has IPSetId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteIPSet');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::WAF::DeleteIPSetResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::WAF::DeleteIPSet - Arguments for method DeleteIPSet on Paws::WAF

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteIPSet on the 
AWS WAF service. Use the attributes of this class
as arguments to method DeleteIPSet.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DeleteIPSet.

As an example:

  $service_obj->DeleteIPSet(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> ChangeToken => Str

  

The value returned by the most recent call to GetChangeToken.










=head2 B<REQUIRED> IPSetId => Str

  

The C<IPSetId> of the IPSet that you want to delete. C<IPSetId> is
returned by CreateIPSet and by ListIPSets.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteIPSet in L<Paws::WAF>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.17.tar.gz: Paws-0.17/lib/Paws/WAF/DeleteIPSet.pm <==

package Paws::WAF::DeleteIPSet;
  use Moose;
  has ChangeToken => (is => 'ro', isa => 'Str', required => 1);
  has IPSetId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteIPSet');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::WAF::DeleteIPSetResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::WAF::DeleteIPSet - Arguments for method DeleteIPSet on Paws::WAF

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteIPSet on the 
AWS WAF service. Use the attributes of this class
as arguments to method DeleteIPSet.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteIPSet.

As an example:

  $service_obj->DeleteIPSet(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> ChangeToken => Str

  The value returned by the most recent call to GetChangeToken.

=head2 B<REQUIRED> IPSetId => Str

  The C<IPSetId> of the IPSet that you want to delete. C<IPSetId> is
returned by CreateIPSet and by ListIPSets.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteIPSet in L<Paws::WAF>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
